#include <SyFi.h>

using namespace GiNaC; 
using namespace SyFi; 
using namespace std; 

int main() {
    ex pi = 3.14; 
    cout <<"pi="<<pi<<endl; 
    ex x = symbol("x"); 
    cout <<"x="<<x<<endl; 
    ex f = cos(x); 
    cout <<"f="<<f<<endl; 
    ex list = lst(pi,x,f); 
    cout <<"list="<<list<<endl; 

    lst list2 = lst(pi,x,f); 
    cout <<"list="<<lst2string(list2)<<endl; 

    for (unsigned int i=0; i< list.nops(); i++) {
        cout <<"item "<<i+1<<" = "<<list[i]<<endl; 
    }

    return 0; 
}
